@@ -3,7 +3,8 @@ require 'spec_helper'
 describe 'aodh::api' do
 
   let :pre_condition do
-    "class { 'aodh': }
+    "include apache
+     class { 'aodh': }
      include aodh::db
      class { 'aodh::keystone::authtoken':
        password => 'a_big_secret',
@@ -17,7 +18,7 @@ describe 'aodh::api' do
     }
   end
 
-  shared_examples 'aodh::api' do
+  shared_examples 'aodh-api' do
 
     it { is_expected.to contain_class('aodh::deps') }
     it { is_expected.to contain_class('aodh::params') }
@@ -32,7 +33,8 @@ describe 'aodh::api' do
     end
 
     it 'configures api' do
-      is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value( 'services' )
+      is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value('services')
+      is_expected.to contain_aodh_config('api/gnocchi_external_domain_name').with_value('Default')
       is_expected.to contain_aodh_config('api/paste_config').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_oslo__middleware('aodh_config').with(
         :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
@@ -40,27 +42,6 @@ describe 'aodh::api' do
       )
     end
 
-    [{:enabled => true}, {:enabled => false}].each do |param_hash|
-      context "when service should be #{param_hash[:enabled] ? 'enabled' : 'disabled'}" do
-        before do
-          params.merge!(param_hash)
-        end
-
-        it 'configures aodh-api service' do
-          is_expected.to contain_service('aodh-api').with(
-            :ensure     => (params[:manage_service] && params[:enabled]) ? 'running' : 'stopped',
-            :name       => platform_params[:api_service_name],
-            :enable     => params[:enabled],
-            :hasstatus  => true,
-            :hasrestart => true,
-            :tag        => 'aodh-service',
-          )
-        end
-        it { is_expected.to contain_service('aodh-api').that_subscribes_to('Anchor[aodh::service::begin]')}
-        it { is_expected.to contain_service('aodh-api').that_notifies('Anchor[aodh::service::end]')}
-      end
-    end
-
     context 'with sync_db set to true' do
       before do
         params.merge!(
@@ -97,13 +78,77 @@ describe 'aodh::api' do
       it { is_expected.to contain_aodh_config('api/paste_config').with_value('/etc/aodh/api-paste.ini') }
     end
 
-    context 'with gnocchi_external_project_owner' do
+    context 'with gnocchi parameters' do
       before do
-        params.merge!({:gnocchi_external_project_owner => 'gnocchi-project' })
+        params.merge!({
+          :gnocchi_external_project_owner => 'gnocchi-project',
+          :gnocchi_external_domain_name   => 'MyDomain'
+        })
       end
 
-      it { is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value('gnocchi-project') }
+      it 'configures gnocchi parameters' do
+        is_expected.to contain_aodh_config('api/gnocchi_external_project_owner').with_value('gnocchi-project')
+        is_expected.to contain_aodh_config('api/gnocchi_external_domain_name').with_value('MyDomain')
+      end
     end
+
+    context 'when service_name is not valid' do
+      before do
+        params.merge!({ :service_name   => 'foobar' })
+      end
+
+      let :pre_condition do
+        "include apache
+         include aodh::db
+         class { 'aodh': }
+         class { 'aodh::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
+      end
+
+      it_raises 'a Puppet::Error', /Invalid service_name/
+    end
+  end
+
+
+  shared_examples_for 'aodh-api without standalone service' do
+
+    let :pre_condition do
+      "include apache
+       include aodh::db
+       class { 'aodh': }
+       class {'aodh::keystone::authtoken':
+         password => 'password',
+       }"
+    end
+
+    it { is_expected.to_not contain_service('aodh-api') }
+  end
+
+
+  shared_examples 'aodh-api with standalone service' do
+
+    [{:enabled => true}, {:enabled => false}].each do |param_hash|
+      context "when service should be #{param_hash[:enabled] ? 'enabled' : 'disabled'}" do
+        before do
+          params.merge!(param_hash)
+        end
+
+        it 'configures aodh-api service' do
+          is_expected.to contain_service('aodh-api').with(
+            :ensure     => (params[:manage_service] && params[:enabled]) ? 'running' : 'stopped',
+            :name       => platform_params[:api_service_name],
+            :enable     => params[:enabled],
+            :hasstatus  => true,
+            :hasrestart => true,
+            :tag        => 'aodh-service',
+          )
+        end
+        it { is_expected.to contain_service('aodh-api').that_subscribes_to('Anchor[aodh::service::begin]')}
+        it { is_expected.to contain_service('aodh-api').that_notifies('Anchor[aodh::service::end]')}
+      end
+    end
+
     context 'with disabled service managing' do
       before do
         params.merge!({
@@ -139,23 +184,6 @@ describe 'aodh::api' do
         )
       end
     end
-
-    context 'when service_name is not valid' do
-      before do
-        params.merge!({ :service_name   => 'foobar' })
-      end
-
-      let :pre_condition do
-        "include apache
-         include aodh::db
-         class { 'aodh': }
-         class { 'aodh::keystone::authtoken':
-           password => 'a_big_secret',
-         }"
-      end
-
-      it_raises 'a Puppet::Error', /Invalid service_name/
-    end
   end
 
   on_supported_os({
@@ -172,15 +200,25 @@ describe 'aodh::api' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          { :api_package_name => 'aodh-api',
-            :api_service_name => 'aodh-api' }
+          if facts[:operatingsystem] == 'Ubuntu'
+            { :api_package_name => 'aodh-api',
+              :api_service_name => 'httpd' }
+          else
+            { :api_package_name => 'aodh-api',
+              :api_service_name => 'aodh-api' }
+          end
         when 'RedHat'
           { :api_package_name => 'openstack-aodh-api',
-            :api_service_name => 'openstack-aodh-api' }
+            :api_service_name => 'httpd' }
         end
       end
 
-      it_behaves_like 'aodh::api'
+      if facts[:osfamily] == 'Debian' and facts[:operatingsystem] != 'Ubuntu'
+        it_behaves_like 'aodh-api with standalone service'
+      else
+        it_behaves_like 'aodh-api without standalone service'
+      end
+      it_behaves_like 'aodh-api'
     end
   end
 
