@@ -2,30 +2,26 @@ require 'spec_helper'
 
 describe 'aodh::evaluator' do
 
-  let :pre_condition do
-    "class { '::aodh': }"
-  end
-
   let :params do
     { :enabled => true }
   end
 
   shared_examples_for 'aodh-evaluator' do
 
-    context 'with coordination' do
+    context 'with defaults' do
+      it 'configures defaults' do
+        is_expected.to contain_aodh_config('evaluator/workers').with_value(4)
+        is_expected.to contain_aodh_config('DEFAULT/evaluation_interval').with_value('<SERVICE DEFAULT>')
+      end
+    end
+
+    context 'with workers' do
       before do
-        params.merge!({ :coordination_url => 'redis://localhost:6379' })
+        params.merge!({ :workers => 8 })
       end
 
-      it 'configures backend_url' do
-        is_expected.to contain_aodh_config('coordination/backend_url').with_value('redis://localhost:6379')
-      end
-
-      it 'installs python-redis package' do
-        is_expected.to contain_package('python-redis').with(
-          :name => platform_params[:redis_package_name],
-	  :tag  => 'openstack'
-        )
+      it 'configures workers' do
+        is_expected.to contain_aodh_config('evaluator/workers').with_value(8)
       end
     end
 
@@ -38,13 +34,23 @@ describe 'aodh::evaluator' do
       end
     end
 
+    context 'with deprecated coordination_url' do
+      before do
+        params.merge!({ :coordination_url => 'redis://localhost:6379' })
+      end
+      it 'configures coordination and workers' do
+        is_expected.to contain_aodh_config('coordination/backend_url').with_value('redis://localhost:6379')
+        is_expected.to contain_aodh_config('evaluator/workers').with_value(4)
+      end
+    end
 
     context 'when enabled' do
       it { is_expected.to contain_class('aodh::params') }
 
       it 'installs aodh-evaluator package' do
-        is_expected.to contain_package(platform_params[:evaluator_package_name]).with(
+        is_expected.to contain_package('aodh-evaluator').with(
           :ensure => 'present',
+          :name   => platform_params[:evaluator_package_name],
           :tag    => ['openstack', 'aodh-package']
         )
       end
@@ -60,6 +66,10 @@ describe 'aodh::evaluator' do
         )
       end
 
+      it 'sets default values' do
+        is_expected.to contain_aodh_config('DEFAULT/evaluation_interval').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_aodh_config('evaluator/workers').with_value(4)
+      end
     end
 
     context 'when disabled' do
@@ -98,34 +108,17 @@ describe 'aodh::evaluator' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({
-          :fqdn           => 'some.host.tld',
-          :concat_basedir => '/var/lib/puppet/concat'
-        }))
+        facts.merge!(OSDefaults.get_facts({ :os_workers => 4 }))
       end
 
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
           { :evaluator_package_name => 'aodh-evaluator',
-            :evaluator_service_name => 'aodh-evaluator',
-            :redis_package_name     => 'python3-redis' }
+            :evaluator_service_name => 'aodh-evaluator' }
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :evaluator_package_name => 'openstack-aodh-evaluator',
-              :evaluator_service_name => 'openstack-aodh-evaluator',
-              :redis_package_name     => 'python3-redis' }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :evaluator_package_name => 'openstack-aodh-evaluator',
-                :evaluator_service_name => 'openstack-aodh-evaluator',
-                :redis_package_name     => 'python3-redis' }
-            else
-              { :evaluator_package_name => 'openstack-aodh-evaluator',
-                :evaluator_service_name => 'openstack-aodh-evaluator',
-                :redis_package_name     => 'python-redis' }
-            end
-          end
+          { :evaluator_package_name => 'openstack-aodh-evaluator',
+            :evaluator_service_name => 'openstack-aodh-evaluator' }
         end
       end
       it_configures 'aodh-evaluator'
