@@ -8,12 +8,23 @@ describe 'aodh::listener' do
 
   shared_examples_for 'aodh-listener' do
 
+    context 'with workers' do
+      let :params do
+        { :workers => 8 }
+      end
+
+      it 'configures workers' do
+        is_expected.to contain_aodh_config('listener/workers').with_value(8)
+      end
+    end
+
     context 'when enabled' do
       it { is_expected.to contain_class('aodh::params') }
 
       it 'installs aodh-listener package' do
-        is_expected.to contain_package(platform_params[:listener_package_name]).with(
+        is_expected.to contain_package('aodh-listener').with(
           :ensure => 'present',
+          :name   => platform_params[:listener_package_name],
           :tag    => ['openstack', 'aodh-package']
         )
       end
@@ -29,6 +40,9 @@ describe 'aodh::listener' do
         )
       end
 
+      it 'sets default values' do
+        is_expected.to contain_aodh_config('listener/workers').with_value(4)
+      end
     end
 
     context 'when disabled' do
@@ -67,7 +81,7 @@ describe 'aodh::listener' do
   }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts())
+        facts.merge!(OSDefaults.get_facts({ :os_workers => 4 }))
       end
 
       let(:platform_params) do
